<?php
/**
 * Plugin Name:          WooCommerce Store Catalog PDF
 * Plugin URI:           https://addify.store/product/woocommerce-store-catalog-pdf/
 * Description:          Enhance your store with WooCommerce Store Catalog PDF. Boost up the product display and downloads for a superior shopping experience.
 * Version:              1.1.0
 * Author:               Adiffy
 * Develop BY:           Addify
 * Author URI:           https://addify.store/
 * Support:              https://addify.store/
 * License:           GNU General Public License v3.0
 * License URI:       http://www.gnu.org/licenses/gpl-3.0.html
 * Text Domain:          addify_wc_sc_pdf
 * WC required at least: 3.0.9
 * WC tested upto: 8.*.*
 */

if ( ! defined( 'ABSPATH' ) ) {
	die();
}
if ( ! class_exists( 'Addify_Woocommerce_Store_Catalog_Pdf' ) ) {
	class Addify_Woocommerce_Store_Catalog_Pdf {
		public function __construct() {
			$this->wc_sc_pdf_const_variables();
			add_action( 'init', array( $this, 'af_wcsc_pdf_woocommerce_check' ) );
			add_action( 'plugins_loaded', array( $this, 'af_wc_sc_pdf_woocommerce_check' ) );
			add_action( 'before_woocommerce_init', array( $this, 'af_wc_sc_pdf_hops_compatibility' ) );

			if ( file_exists( __DIR__ . '/vendor/autoload.php' ) ) {
				require_once __DIR__ . '/vendor/autoload.php';
			}
		}
		public function af_wcsc_pdf_woocommerce_check() {
			if ( defined( 'WC_PLUGIN_FILE' ) ) {
				add_action( 'after_setup_theme', array( $this, 'af_wc_sc_pdf_load_text_domain' ) );
				require_once AF_WC_SC_PDF_PLUGIN_DIR . 'assets/ajax-controller/class-af-wc-ajax-controller.php';
				require_once AF_WC_SC_PDF_PLUGIN_DIR . 'includes/af-woocommerce-store-catalog-general-functions.php';

				if ( is_admin() ) {
					require_once AF_WC_SC_PDF_PLUGIN_DIR . 'includes/admin/class-af-woocomerce-store-catalog-pdf-admin.php';
				} else {
					require_once AF_WC_SC_PDF_PLUGIN_DIR . 'includes/front/class-af-woocommerce-store-catalog-pdf-front.php';
				}
			}
		}
		public function af_woocommerce_store_catalog_pdf_wc_active() {
			deactivate_plugins( __FILE__ );
			?>
			<div id="message" class="error">
				<p>
					<strong>
						<?php echo esc_html__( 'WooCommerce Store Catalog PDF plugin is inactive. WooCommerce plugin must be active in order to activate it.', 'addify_wc_sc_pdf' ); ?>
					</strong>
				</p>
			</div>
			<?php
		}
		public function af_wc_sc_pdf_woocommerce_check() {
			if ( ! is_multisite() && ( ! in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ), true ) ) ) {
				add_action( 'admin_notices', array( $this, 'af_woocommerce_store_catalog_pdf_wc_active' ) );

			}
		}
		public function wc_sc_pdf_const_variables() {
			if ( ! defined( 'AF_WC_SC_PDF_PLUGIN_URL' ) ) {
				define( 'AF_WC_SC_PDF_PLUGIN_URL', plugin_dir_url( __FILE__ ) );
			}
			if ( ! defined( 'AF_WC_SC_PDF_PLUGIN_DIR' ) ) {
				define( 'AF_WC_SC_PDF_PLUGIN_DIR', plugin_dir_path( __FILE__ ) );
			}
		}
		public function af_wc_sc_pdf_hops_compatibility() {
			if ( class_exists( \Automatic\WooCommerce\Utitlities\FeaturesUtil::class ) ) {
				\Automattic\WooCommerce\Utilities\FeaturesUtil::declare_compatibility( 'custom_order_tables', __FILE__, true );
			}
		}
		public function af_wc_sc_pdf_load_text_domain() {
			if ( function_exists( 'load_plugin_textdomain' ) ) {
				load_plugin_textdomain( 'addify_wc_sc_pdf', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );
			}
		}
	}
}
new Addify_Woocommerce_Store_Catalog_Pdf();
?>
